@@ -8,12 +8,12 @@
 
 import re
 
-from django.conf import settings
+from framework.conf import settings
 from django.contrib.staticfiles.storage import staticfiles_storage
 from django.template.backends.jinja2 import Jinja2
 from django.template.library import import_library
 from django.urls import reverse
-from django.utils.translation import gettext, ngettext
+from django.utils.translation import gettext_lazy, ngettext_lazy
 from jinja2 import Environment
 
 
@@ -28,7 +28,7 @@ filters = []
 
 def environment(**options):
     env = Environment(extensions=['jinja2.ext.i18n'], **options)
-    env.install_gettext_callables(gettext=gettext, ngettext=ngettext, newstyle=True)
+    env.install_gettext_callables(gettext=gettext_lazy, ngettext=ngettext_lazy, newstyle=True)
 
     from django.template.defaultfilters import register as django_default_register
     env.filters.update(django_default_register.filters)
