@@ -16,6 +16,7 @@ from django.utils.encoding import force_bytes
 from django.utils.translation import gettext_lazy as _
 from rest_framework import serializers
 from rest_framework.fields import DictField, CharField
+from sqlalchemy import null
 
 from .utils import json_dumps, ObjectDict, trace_msg
 from .utils.cache import CachedClassAttribute
@@ -336,8 +337,8 @@ class BaseModelMixin(SqlModelMixin):
                 self.set_attr(f.name, data, null=True)
 
     def set_attr(self, name, value, value_handler=None, null=False):
-        '''设置模型的属性
-        '''
+        """设置模型的属性
+        """
 
         if value_handler:
             value = value_handler(value)
@@ -349,7 +350,8 @@ class BaseModelMixin(SqlModelMixin):
         d = {}
         for field in self._meta.fields:
             attr = field.name
-            attr_value = getattr(self, attr)
+
+            attr_value = self.__dict__.get(attr)  # getattr(self, attr)
 
             # 特殊处理datetime的数据
             if isinstance(attr_value, datetime.datetime) and is_msgpack:
@@ -360,9 +362,9 @@ class BaseModelMixin(SqlModelMixin):
             elif isinstance(attr_value, BaseModel):
                 d[attr] = attr_value.get_dict(has_m2mfields=has_m2mfields, is_msgpack=is_msgpack)
             elif isinstance(attr_value, (int, str, float)):
-                d[attr] = getattr(self, attr)
+                d[attr] = attr_value
             elif not is_msgpack:
-                d[attr] = field.get_prep_value(getattr(self, attr))
+                d[attr] = field.get_prep_value(attr_value)
 
         if has_m2mfields:
             m2mfields = self.__class__._meta.many_to_many
@@ -405,7 +407,7 @@ class BaseModelMixin(SqlModelMixin):
                 return x.verbose_name
 
     @classmethod
-    def get_list_view_name(cls,model_class=None):
+    def get_list_view_name(cls, model_class=None):
         model_class = model_class or cls
         return '%s.%s.list' % (model_class._meta.app_label, cls.get_lower_name(model_class))
 
@@ -483,8 +485,8 @@ class BaseModel(models.Model, BaseModelMixin):
     id = models.BigAutoField(primary_key=True)
     _version = models.IntegerField(_("版本"), default=0, null=False)
     # auto_now_add = True    #创建时添加的时间  修改数据时，不会发生改变
-    create_datetime = models.DateTimeField(_("创建时间"), auto_now_add=True, blank=True)
-    update_datetime = models.DateTimeField(_("更新时间"), auto_now=True, blank=True)
+    create_datetime = models.DateTimeField(_("创建时间"), auto_now_add=True, blank=True, null=False, db_index=True)
+    update_datetime = models.DateTimeField(_("更新时间"), auto_now=True, blank=True, null=False)
 
     class Meta:
         abstract = True
