@@ -6,6 +6,6 @@
 # @Contact : xzregg@gmail.com
 # @Desc    : 
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from rest_framework.negotiation import DefaultContentNegotiation
\ No newline at end of file
