@@ -13,3 +13,13 @@ from .utils import MyJsonEncoder
 
 class JSONRenderer(RestJSONRenderer):
     encoder_class = MyJsonEncoder
+
+
+class DebugRenderer(JSONRenderer):
+    format = 'debug'
+
+    media_type = 'text/html'
+
+    def render(self, *args, **kwargs):
+        rsp = super().render( *args, **kwargs)
+        return b'<body>%s</body>' % rsp
